@@ -1,10 +1,11 @@
 import json
+
 from bunch import Bunch
 
 
 def dict2json(dict_, json_filepath):
     """
-    Convert a python dict to a json file
+    Convert a python dict to a json file.
 
     Args:
         dict_ (dict): the dict to serialize
@@ -16,11 +17,11 @@ def dict2json(dict_, json_filepath):
 
 def dict2namespace(dict_):
     """
-    Convert a python dict to a Bunch namespace
+    Convert a python dict to a Bunch namespace.
 
     Args:
         dict_ (dict): the dict to convert
-    Return:
+    Returns:
         (Bunch)
     """
     return Bunch(dict_)
@@ -28,11 +29,11 @@ def dict2namespace(dict_):
 
 def json2dict(json_filepath):
     """
-    Convert json filepath to a python dict
+    Convert `json_filepath` to a python dict.
 
     Args:
         json_filepath (str): path to the json file
-    Return:
+    Returns:
         (dict)
     """
     with open(json_filepath, 'r') as json_fp:
@@ -41,11 +42,11 @@ def json2dict(json_filepath):
 
 def json2namespace(json_filepath):
     """
-    Convert json filepath to a Bunch namespace
+    Convert `json_filepath` to a Bunch namespace.
 
     Args:
         json_filepath (str): path to the json file
-    Return:
+    Returns:
         (Bunch)
     """
     return dict2namespace(json2dict(json_filepath))
@@ -53,9 +54,9 @@ def json2namespace(json_filepath):
 
 def Config(**kwargs):
     """
-    Shortcut function for creating a config object from keyword arguments
+    Shortcut function for creating a config object from keyword arguments.
 
-    Return:
+    Returns:
         (Bunch)
     """
     return dict2namespace(dict(**kwargs))
